==> tomee-project-7.0.1-source-release.zip: tomee-project-7.0.1/examples/polling-parent/polling-client/src/main/java/jug/client/command/impl/PollResultCommand.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * <p/>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p/>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jug.client.command.impl;

import jug.client.command.api.AbstractCommand;
import jug.client.command.api.Command;

import javax.ws.rs.core.Response;

import static jug.client.command.impl.PollResultCommand.RESULT_CMD;

@Command(name = RESULT_CMD, usage = RESULT_CMD + " <name>", description = "result of a poll")
public class PollResultCommand extends AbstractCommand {

    public static final String RESULT_CMD = "result";

    @Override
    protected Response invoke(String cmd) {
        if (RESULT_CMD.length() + 1 >= cmd.length()) {
            System.err.println("please specify a poll name");
            return null;
        }

        return client.path("api/subject/result/".concat(cmd.substring(RESULT_CMD.length() + 1))).get();
    }
}

==> tomee-project-10.1.4-source-release.zip: tomee-project-10.1.4/examples/polling-parent/polling-client/src/main/java/jug/client/command/impl/PollResultCommand.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jug.client.command.impl;

import jug.client.command.api.AbstractCommand;
import jug.client.command.api.Command;

import jakarta.ws.rs.core.Response;

import static jug.client.command.impl.PollResultCommand.RESULT_CMD;

@Command(name = RESULT_CMD, usage = RESULT_CMD + " <name>", description = "result of a poll")
public class PollResultCommand extends AbstractCommand {

    public static final String RESULT_CMD = "result";

    @Override
    protected Response invoke(String cmd) {
        if (RESULT_CMD.length() + 1 >= cmd.length()) {
            System.err.println("please specify a poll name");
            return null;
        }

        return client.path("api/subject/result/".concat(cmd.substring(RESULT_CMD.length() + 1))).get();
    }
}
